@@ -14,7 +14,8 @@ sub setup {
 			production  => 'Production',
 			development => [
 				'Development' => '<APP_NAME>',
-				'DevYoshizu'  => 'seagirl|yoshizu|tak|sb106|sb245|sb191',
+				'DevDocker'   => 'docker',
+				'DevYoshizu'  => 'seagirl',
 			],
 		},
  	);
@@ -25,9 +26,10 @@ sub setup {
 	);
 
 	$self->load_plugins(
-		'URL'     => undef,
-		'Now'     => { time_zone => 'Asia/Tokyo' },
-		'Runtime' => {
+		'URL'       => undef,
+		'Now'       => { time_zone => 'Asia/Tokyo' },
+		'Proctitle' => {},
+		'Runtime'   => {
 			cli    => 0,
 			ignore => 'Production'
 		},
