@@ -8,6 +8,7 @@ use Image::Info qw/image_type/;
 use JSON;
 use MIME::Base64 qw(decode_base64 decoded_base64_length);
 use Scalar::Util qw/looks_like_number/;
+use UNIVERSAL::require;
 
 
 rule NOT_NULL => sub {
@@ -39,8 +40,8 @@ rule UINT => sub {
 rule BIGINT => sub {
 	return 0 unless $_ =~ /\A[+\-]?[0-9]+\z/;
 	return 1 if $_ =~ /\A[+\-]?[0-9]{1,18}\z/;
-	return 1 if $_ =~ /\A[+]?[0-9]{20,}\z/;
-	return 1 if $_ =~ /\A[\-]?[0-9]{20,}\z/;
+	return 0 if $_ =~ /\A[+]?[0-9]{20,}\z/;
+	return 0 if $_ =~ /\A[\-]?[0-9]{20,}\z/;
 	Math::BigInt->use or die;
 	my $MIN = Math::BigInt->new("-9223372036854775808");
 	my $MAX = Math::BigInt->new("9223372036854775807");
@@ -53,7 +54,7 @@ rule BIGINT => sub {
 rule BIGUINT => sub {
 	return 0 unless $_ =~ /\A[0-9]+\z/;
 	return 1 if $_ =~ /\A[0-9]{1,18}\z/;
-	return 1 if $_ =~ /\A[0-9]{20,}\z/;
+	return 0 if $_ =~ /\A[0-9]{20,}\z/;
 	Math::BigInt->use or die;
 	my $MAX = Math::BigInt->new("9223372036854775807");
 	my $val = Math::BigInt->new($_);
@@ -321,6 +322,14 @@ filter TRIM => sub {
 	$value;
 };
 
+# remove control character other than LF or CR
+filter RCC => sub {
+	my ($value, $args, $opts) = @_;
+	return $value unless $value;
+	$value =~ s/[\x00-\x09\x0b\x0c\x0e-\x1f]//g;
+	$value;
+};
+
 filter DEFAULT => sub {
 	my ($value, $args, $opts) = @_;
 	unless (defined $value) {
